/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */

 




package org.greenstone.gatherer.gui.table;

import java.awt.Component;
import javax.swing.DefaultCellEditor;
import javax.swing.JTable;
import javax.swing.JTextField;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.msm.Metadata;
import org.greenstone.gatherer.gui.combobox.GComboBox;
import org.greenstone.gatherer.gui.combobox.GComboBoxModel;
/** This implementation of the TableCellRenderer interface allows for us
 * to return a GComboBox with the correct model given a reference to the
 * original metadata row within the given table. All edit calls, other than
 * those from the third column, ie the values column, get the default 
 * editor component.
 */
public class GTableCellEditor
	 extends DefaultCellEditor {

	 private Gatherer        gatherer      = null;

	 private GComboBox      editor       = null;

	 private GComboBoxModel editor_model = null;

	 /** The default constructor simply add the standard new argument, a 
	  * reference to the Gatherer class.
	  * @param gatherer A reference to Gatherer for communication and dictionary 
	  * purposes.
	  */
	 public GTableCellEditor(Gatherer gatherer) {
		  super(new JTextField());
		  this.gatherer = gatherer;
	 }

	 /** This method returns the currently selected value of our editor
	  * GCombobox.
	  * @return An Object which is the selected items value.
	  */
	 public Object getCellEditorValue() {
		  return editor.getSelectedItem();
	 }

	 /** Returns a reference to the editor GComboBox.
	  * @return A Component reference to our editor.
	  */
	 public Component getComponent() {
		  return editor;
	 }

	 /** This method is called to retrieve the correct editor component for
	  * a certain row and column within the target JTable. It is here that
	  * we create the custom GComboBox for each row of the 'values' column
	  * using a different model for each. If the call comes from any other 
	  * column (which it shouldn't but what the hell) we let the super
	  * handle it which returns a plain old JTextField as the editing component.
	  * @param table The JTable which called this method.
	  * @param value The initial value of the cell this editor will be used
	  * for, as an Object. Format this to suit the editor you wish to return.
	  * @param isSelected A Boolean specifying whether the selected cell
	  * is currently highlighted in such a way so as to allow the user to
	  * know it is being edited.
	  * @param row An Int specifying the cells row.
	  * @param column An Int specifying the cells column.
	  * @return A Component which will be placed in the table as the method
	  * of editing the specified cell.
	  */
	 public Component getTableCellEditorComponent(JTable table, Object value,
																 boolean isSelected, int row,
																 int column) {
		  GTableModel model = (GTableModel)table.getModel();
		  // Create a new GComboBox with a model based on the selected
		  // records metadata.
		  Metadata selected_metadata = model.getMetadataAtRow(row);
		  //editor_model = gatherer.c_man.getCollection().getValueModel
		  //	(selected_metadata.element);
		  editor = new GComboBox(editor_model);
		  editor.setEditable(true);
		  // Make sure that value is the currently selected option in the 
		  // editor.
		  editor.setSelectedItem(value);
		  // Done.
		  return editor;
	 }
}

